HackPurgatory SEON Email Endpoint (Created by @RIPNetwork)

Consulta donde esta un email registrado en mas de 600 sitios con OSINT sin limitaciones y de forma gratuita usando este proyecto. Puedes unirte a nuestra comunidad con los siguientes enlaces:

Link: https://hackpurgatory.es
Link: https://hackpurgatory.es

Somos una comunidad que se dedica a enseñar y ayudar de forma gratuita sin pedir nada a cambio, buscamos mejorar internet y hacerlo mas seguro. Puedes unirte si te apetece a nuestro canal de difusión.

Link: https://t.me/HackPurgatory

Si necesitas un Tutorial sobre como instalar este repositorio correctamente puedes visitar nuestro canal de YouTube.

Link: https://www.youtube.com/@RIPNetwork

Instalación
```bash

pip install hackpurgatory-seonmail

hackpurgatory-seonmail -e test@gmail.com





